# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Plant trait landscapes:
# Authors: 
# 
# Code Notes:
# Data manipulation for spatial correlates
# Processing of Landsat (EVI), Elevation, Aspect, Slope, Forest Resource Inventory, and the CEC landcover dataset
# Extract of spatial co-variate values happens at the end
# If steps where done in ArcGIS, the details of those steps are described in this code
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 

# Set working directory
setwd("~/Dropbox (HeckfordT)/PhD_Thesis/Chapter_PlantTraitLandscapes/")

# Install/load the following packages
library(easypackages)
libraries("raster", "sp", "colorspace")

# This analysis is bounded within our Area Of Interest (AOI).
# The AOI is the ecodistrict (468)
# Areas of no data exists in the NW corner (fingers; no FRI), and bottom (south point; no EVI - edge of landsat scene)
AOI <- shapefile("Data/Spatial/Processing/AOI/EcoDistr_AOI.shp")
plot(AOI)

#### Enhanced Vegetation Index processing ####
# Preprocessing done in ArcGIS
# Screenshots recorded for site cloudiness scene interrogation 
# For each scene:
# Using the Landsat Quality Assessment (QA) ArcGIS Toolbox
# We used the DecodeQA script to code pixel band bits of the Pixel_QA band.
# The following raster (Decoded QA bits) was used to confirm clouds from the MLT (RGB) band.
# We used the ExtractQA script to extract and combine pixel reliability bits for cloud/snow
# Bits were selected for Cloud Shadow, Snow, Cloud, High Cloud Confidence, High Cirrus Confidence
# The resulting selected bits were combined into a single raster where 1 = clouds and 0 = no clouds, and NoData
# Cloud masks were clipped to the AOI (Extract by Mask)
# Cloud masks were reclassified to 0 = clouds, and 1 = NoData, along with NoData
# EVI Landsat scene were clipped to the AOI (Extract by Mask)
# Using Extract by Mask, cloudy pixels from the cloud masks were removed from each EVI scene
# Here, we import EVI scene that are cloud free

# Load Scene 1; June 28, 2016 
Scene1_EVI <- raster("Data/Spatial/Processing/Landsat8/EVI_Scenes_ForR/Scene1_EVI.tif")
# Load Scene 2; August 15, 2016 
Scene2_EVI <- raster("Data/Spatial/Processing/Landsat8/EVI_Scenes_ForR/Scene2_EVI.tif")
# Load Scene 3; September 16, 2016
Scene3_EVI <- raster("Data/Spatial/Processing/Landsat8/EVI_Scenes_ForR/Scene3_EVI.tif")

# Rescale EVI Scenes by 0.0001
Scene1EVI_rescale <- Scene1_EVI*0.0001
Scene2EVI_rescale <- Scene2_EVI*0.0001
Scene3EVI_rescale <- Scene3_EVI*0.0001

# Create a raster brich with the three scenes
EVI_Brick <- brick(list(Scene1EVI_rescale, Scene2EVI_rescale, Scene3EVI_rescale))

# Plot Scenes
# Export graph
myTheme <- rasterTheme(region=sequential_hcl(6, power=0.8))
LayerNames <- c("June 28, 2016", "August 15, 2016", "September 16, 2016")
png("Deliverables/EVI_Interpolation/EVI_Original.png", width = 8, height = 6, units = "in", res = 600)
levelplot(EVI_Brick, par.settings = myTheme, names.attr = LayerNames)
dev.off()
# Perform a linear interpolation between EVI time scenes to populate no data areas
# First check the distribution of elevation values in the raster
png("Deliverables/EVI_Interpolation/EVI_HistOriginal.png", width = 8, height = 6, units = "in", res = 600)
hist(EVI_Brick) # The vegetation component of these data are normal; values 0 < or = 0 = water/NA
dev.off()

EVI_approx <- approxNA(EVI_Brick, method="linear", rule=2) # linear because hist = normal; rule 2 = remove all NAs; rule 1 some NA's retain via interpolation search constraints.

# Plot Scenes
LayerNamesInterp <- c(" ", " ", " ")

png("Deliverables/EVI_Interpolation/EVI_Interpolate.png", width = 8, height = 6, units = "in", res = 600)
levelplot(EVI_approx, par.settings = myTheme, names.attr = LayerNamesInterp)
dev.off()

# Recheck histogram
png("Deliverables/EVI_Interpolation/EVI_HistInterpolate.png", width = 8, height = 6, units = "in", res = 600)
hist(EVI_approx) 
dev.off()


writeRaster(EVI_approx, "Data/Spatial/Processing/Landsat8/EVI_approx/ApproxNA", format="GTiff", bylayer=T, suffix="names")

# Average rasters together
EVI_mean <-calc(EVI_approx, fun = mean)
plot(EVI_mean)
writeRaster(EVI_mean, "Data/Spatial/ForDistributionModelling/EVI/EVI_NonScaled_ForSampPts.tif")

# Standardize the EVI mean for use in StDMs
EVI_trans <- raster.transformation(EVI_mean, trans="std")
plot(EVI_trans)
writeRaster(EVI_trans,"Data/Spatial/ForDistributionModelling/EVI/EVI_Scaled.tif")

#### Terrain processing #### 
# A Canadian Digital Elevation Model was acquired from http://geogratis.gc.ca/ at 20-metre resolution.
# In ArcGIS, I combined all 4 geotiffs together to create a seamless frame 
# Clipped the DEM to the AOI
# Resampled DEM to a 30 meter resolution (limited res by EVI) using bilinear interpolation
# Resampled DEM was aligned with EVI

# Load the Digital Elevation Model
DEM <- raster("Data/Spatial/Processing/CDEM/Final_ForR/DEM_AOI_Resamp.tif")
# Since we will be using the original DEM to extract values at sample locations, I will re-save this raster into the StDMs directory
writeRaster(DEM, "Data/Spatial/ForDistributionModelling/DEM/DEM_NonScaled_ForSampPts.tif")
# Standardize the DEM
DEM.trans <- raster.transformation(DEM, trans="std")
# Save the DEM ready for StDMs
writeRaster(DEM.trans,"Data/Spatial/ForDistributionModelling/DEM/DEM_Scaled.tif", overwrite=T)

# Create a aspect layer from the DEM
Aspect <- terrain(DEM, opt="aspect", unit="degrees")
# Use the round function to set aspect values to integers 
Aspect.round <- round(Aspect)
# Load the AspectNormalized csv file - this tells R which values to use when we replace values to scale the aspect layer from 0-360 to 0-180
Norm <- read.csv("Data/Spatial/Legend/AspectNormalizeLegend/AspectNormalize.csv")
# Use the subs function to normalize the aspect layer
Aspect.norm <- subs(Aspect.round, Norm, which="Replace")
# The non standardized raster will be use in the modelling
writeRaster(Aspect.norm, "Data/Spatial/ForDistributionModelling/Aspect/Aspect_NonScaled_ForSampPts.tif")
# Standardize the aspect 
Aspect.trans <- raster.transformation(Aspect.norm, trans="std")
# Save aspect ready for StDMs
writeRaster(Aspect.trans,"Data/Spatial/ForDistributionModelling/Aspect/Aspect_Scaled.tif", overwrite=T)

# Create a slope layer from the DEM
Slope <- terrain(DEM, opt="slope", unit="degrees")
# The non standardized raster will be used for modelling
writeRaster(Slope, "Data/Spatial/ForDistributionModelling/Slope/Slope_NonScaled_ForSampPts.tif")
# Standardize slope raster
Slope.trans <- raster.transformation(Slope, trans="std")
# Save slope rady for StDMs
writeRaster(Slope.trans, "Data/Spatial/ForDistributionModelling/Slope/Slope_Scaled.tif", overwrite=T)

# Elevation, aspect, and slope were masked using the extract by mask with a rasterized FRI inference forests mask.

##### Forest Resource Inventory processing ####
# The Forest Resource Inventory (FRI) from the Prov Gov't of NL and Parks Canada, Terra Nova Nationlal Park (forest and non-forest datasets) were used to derived forest stand metrics.
# In ArcGIS, I set all spatial layers to the correct projection using the "Project" tool.
# In ArcGIS, I clipped all spatial layers to the AOI.
# Processing FRI. This only applies to FRI data from the Prov. Gov't of NL. In ArcMap, join tables to the FRI layer. Table 1: StockedCommercial and Table 2: StockedNonCommercial using the FORESTID field. We had two FRI Prov with overlapping and nonoverlapping extents, using the "ERASE" tool I erased one layer against the other and then used the "MERGE" tool to make a single FIR Prov Govt NL layer, this layer was then "ERASED" against the TNNP FRI layer (I assumed FRI from TNNP was more accurate then the Prov layer, given its a smaller area and I suspect Parks Canada used more expensive techniques to classify and delineate FRI ploygons), following the erase I again used the "MERGE" tool to merge the Prov Gov't NL and TNNP FRI layers together. Following this I used the ERASE tool to remove overlapping boundaries with the non-forest FRI data from the NL Prov Gov't, then I merge this dataset together. Finally, I clip this FRI dataset to the TERG AOI and set the projection and extent to match EVI and DEM data sources

# Load the FRI data
FRI <- shapefile("Data/Spatial/Processing/FRI/Final_FromArcForR/FRI_FinalFinal.shp")
# Checked field names
head(FRI)
# Subset data based on fields of interest
FRI.a<-subset(FRI, select = c(AGE_CODE, AGE_CLASS, HGT_CODE, HGT_CODE_1, HEIGHT_CL, CDEN_CODE, DENSITY_CO, CDEN_COD_1, SPCOMP, SPECIES_CO, COVERTYPE))
# Check to make sure we got all the fields we wanted and in the proper order
head(FRI.a)

# Clean up attributes by combining similar fields in the FRI database
# Age class fields
FRI.a$AgeClass <- paste(FRI.a$AGE_CODE, FRI.a$AGE_CLASS)
FRI.a$AgeClass <- gsub("NA","",FRI.a$AgeClass)
FRI.a$AgeClass <- gsub('\\s+', '', FRI.a$AgeClass)

# Height class fields
FRI.a$HeightClass <- paste(FRI.a$HGT_CODE, FRI.a$HGT_CODE_1, FRI.a$HEIGHT_CL)
FRI.a$HeightClass <- gsub("NA","", FRI.a$HeightClass)
FRI.a$HeightClass <- gsub('\\s+', '', FRI.a$HeightClass)

# Crown density fields
FRI.a$CrownDensity <- paste(FRI.a$CDEN_CODE, FRI.a$DENSITY_CO, FRI.a$CDEN_COD_1)
FRI.a$CrownDensity <- gsub("NA","",FRI.a$CrownDensity)
FRI.a$CrownDensity <- gsub('\\s+', '', FRI.a$CrownDensity)

# Species composition fields
FRI.a$SppComp <- paste(FRI.a$SPCOMP, FRI.a$SPECIES_CO, FRI.a$COVERTYPE)
FRI.a$SppComp <- gsub("NA","",FRI.a$SppComp)
FRI.a$SppComp <- gsub('\\s+', '', FRI.a$SppComp)

# Create a subset dataset with just these fields
FRI.a<-subset(FRI.a, select = c(AgeClass, HeightClass, CrownDensity, SppComp))

# Export the cleaned up FRI dataset
# Use this layer to rasterize layers height class, age class, and crown density in ArcGIS
writeOGR(FRI.a, ".", dsn = "Data/Spatial/ForDistributionModelling/FRI/Shapefile", layer = "FRI_StDMs_1", driver="ESRI Shapefile", overwrite_layer = T)
# In ArcGIS I selected bS, wS and wB dominant forest stands and exported a vector dataset for a mask
# From this mask FRI dataset I clean up the attributes for age class, height class and crown density making sure there were no 0 values, if there was I set them to the largest number strong following the last factor value
# From this mask I rasterized each variable: age class, height class, and crown density with the polygon to raster tool
# I then reclassified each raster layer using the vector values for each variable since ArcGIS assigns them a different pixel value then what is found in the factor levels of the original variable - this was a age class four raster has a four pixel value
# The FRI mask was subsequently saved as a stand alone shapefile and as a raster in the Mask folder

##### CEC land cover data ######
# Clipped to the AOI and reprojected and set extent to that of the other rasters
# Pixel values were extracted by mask using the FRI inference forests only raster mask in ArcGIS
# Subsequent subsetting of raster values occurs below with putting all the layers into one folder
# Reclassified in arc gis for codes 1,5,6 - sample point data

##### Finalize raster layers for use in distribution modelling #####
# load scaled and masked elevation, aspect, slope, and EVI rasters
Elevation <- raster("Data/Spatial/ForDistributionModelling/DEM/DEM_Scaled_Masked.tif")
Slope <- raster("Data/Spatial/ForDistributionModelling/Slope/Slope_Scaled_Masked.tif")
Aspect <- raster("Data/Spatial/ForDistributionModelling/Aspect/Aspect_Scaled_Masked.tif")
EVI <- raster("Data/Spatial/ForDistributionModelling/EVI/EVI_Scaled_Masked.tif")

# Load FRI categorical rasters - binary layers were made in raster calculator - ESRI
LandCover1 <- raster("Data/Spatial/ForDistributionModelling/LandCover/Binary/LandCover1.tif")
LandCover5 <- raster("Data/Spatial/ForDistributionModelling/LandCover/Binary/LandCover5.tif")
LandCover6 <- raster("Data/Spatial/ForDistributionModelling/LandCover/Binary/LandCover6.tif")
AgeClss2 <- raster("Data/Spatial/ForDistributionModelling/FRI/AgeClass_Raster/Binary_FromArc/AgeClss2.tif")
AgeClss3 <- raster("Data/Spatial/ForDistributionModelling/FRI/AgeClass_Raster/Binary_FromArc/AgeClss3.tif")
AgeClss4 <- raster("Data/Spatial/ForDistributionModelling/FRI/AgeClass_Raster/Binary_FromArc/AgeClss4.tif")
AgeClss5 <- raster("Data/Spatial/ForDistributionModelling/FRI/AgeClass_Raster/Binary_FromArc/AgeClss5.tif")
CrwnDns1 <- raster("Data/Spatial/ForDistributionModelling/FRI/CrownDensity_Raster/Binary_FromArc/CrwnDns1.tif")
CrwnDns2 <- raster("Data/Spatial/ForDistributionModelling/FRI/CrownDensity_Raster/Binary_FromArc/CrwnDns2.tif")
CrwnDns3 <- raster("Data/Spatial/ForDistributionModelling/FRI/CrownDensity_Raster/Binary_FromArc/CrwnDns3.tif")
CrwnDns4 <- raster("Data/Spatial/ForDistributionModelling/FRI/CrownDensity_Raster/Binary_FromArc/CrwnDns4.tif")
HghtCls2 <- raster("Data/Spatial/ForDistributionModelling/FRI/HeightClass_Raster/Binary_FromArc/HghtCls2.tif")
HghtCls3 <- raster("Data/Spatial/ForDistributionModelling/FRI/HeightClass_Raster/Binary_FromArc/HghtCls3.tif")
HghtCls4 <- raster("Data/Spatial/ForDistributionModelling/FRI/HeightClass_Raster/Binary_FromArc/HghtCls4.tif")
HghtCls5 <- raster("Data/Spatial/ForDistributionModelling/FRI/HeightClass_Raster/Binary_FromArc/HghtCls5.tif")


# Now set total extent of all layers
Total.Extent.all <- Elevation + Aspect + Slope + EVI + LandCover1 + LandCover5 + LandCover6 + AgeClss2 + AgeClss3 + AgeClss4 + AgeClss5 + HghtCls2 + HghtCls3 + HghtCls4 + HghtCls5 + CrwnDns1 + CrwnDns2 + CrwnDns3 + CrwnDns4

Elevation.crop <- crop(Elevation, Total.Extent.all)
Aspect.crop <- crop(Aspect, Total.Extent.all)
Slope.crop <- crop(Slope, Total.Extent.all)
EVI.crop <- crop(EVI, Total.Extent.all)
LandCover1.crop <- crop(LandCover1, Total.Extent.all)
LandCover5.crop <- crop(LandCover5, Total.Extent.all)
LandCover6.crop <- crop(LandCover6, Total.Extent.all)
AgeClss2.crop <- crop(AgeClss2, Total.Extent.all)
AgeClss3.crop <- crop(AgeClss3, Total.Extent.all)
AgeClss4.crop <- crop(AgeClss4, Total.Extent.all)
AgeClss5.crop <- crop(AgeClss5, Total.Extent.all)
HghtCls2.crop <- crop(HghtCls2, Total.Extent.all)
HghtCls3.crop <- crop(HghtCls3, Total.Extent.all)
HghtCls4.crop <- crop(HghtCls4, Total.Extent.all)
HghtCls5.crop <- crop(HghtCls5, Total.Extent.all)
CrwnDns1.crop <- crop(CrwnDns1, Total.Extent.all)
CrwnDns2.crop <- crop(CrwnDns2, Total.Extent.all)
CrwnDns3.crop <- crop(CrwnDns3, Total.Extent.all)
CrwnDns4.crop <- crop(CrwnDns4, Total.Extent.all)

# Create raster stack - if it works then all the rasters are align - QA check in Arc to make sure
Raster.stack <- stack(Elevation.crop, Aspect.crop, Slope.crop, EVI.crop, LandCover1.crop, LandCover5.crop, LandCover6.crop, AgeClss2.crop, AgeClss3.crop, AgeClss4.crop, AgeClss5.crop, HghtCls2.crop, HghtCls3.crop, HghtCls4.crop, HghtCls5.crop, CrwnDns1.crop, CrwnDns2.crop, CrwnDns3.crop, CrwnDns4.crop)


writeRaster(Elevation.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/Elevation.tif")
writeRaster(Aspect.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/Aspect.tif")
writeRaster(Slope.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/Slope.tif")
writeRaster(EVI.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/EVI.tif")
writeRaster(LandCover1.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/LandCover1.tif")
writeRaster(LandCover5.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/LandCover5.tif")
writeRaster(LandCover6.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/LandCover6.tif")
writeRaster(AgeClss2.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/AgeClss2.tif")
writeRaster(AgeClss3.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/AgeClss3.tif")
writeRaster(AgeClss4.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/AgeClss4.tif")
writeRaster(AgeClss5.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/AgeClss5.tif")
writeRaster(HghtCls2.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/HghtCls2.tif")
writeRaster(HghtCls3.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/HghtCls3.tif")
writeRaster(HghtCls4.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/HghtCls4.tif")
writeRaster(HghtCls5.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/HghtCls5.tif")
writeRaster(CrwnDns1.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/CrwnDns1.tif")
writeRaster(CrwnDns2.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/CrwnDns2.tif")
writeRaster(CrwnDns3.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/CrwnDns3.tif")
writeRaster(CrwnDns4.crop, "Data/Spatial/ForDistributionModelling/FinalRasterStack/CrwnDns4.tif")

##### Spatial extraction of co-variate values #####
# Load layers and extract values of spatial co-variates
Elevation <- raster("Data/Spatial/ForDistributionModelling/DEM/DEM_NonScaled_ForSampPts.tif")
Slope <- raster("Data/Spatial/ForDistributionModelling/Slope/Slope_NonScaled_ForSampPts.tif")
Aspect <- raster("Data/Spatial/ForDistributionModelling/Aspect/Aspect_NonScaled_ForSampPts.tif")
EVI <- raster("Data/Spatial/ForDistributionModelling/EVI/EVI_NonScaled_ForSampPts.tif")

AgeClss <- raster("Data/Spatial/ForDistributionModelling/FRI/AgeClass_Raster/Raster/FRI_AgeClass_Reclass.tif")
CrwnDns <- raster("Data/Spatial/ForDistributionModelling/FRI/CrownDensity_Raster/Raster/FRI_CrownDensity_Reclass.tif")
HghtCls <- raster("Data/Spatial/ForDistributionModelling/FRI/HeightClass_Raster/Raster/FRI_HeightClass_Reclass.tif")
LandCover <- raster("Data/Spatial/Processing/CEC_Landcover/LandCover_FRI_Mask.tif")

a <- raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/FRI_Reclass/AgeClss.tif")
str(a)

c <- layerize(a, values=c(2,3,4,5))
plot(c)

# Add together to get total extent
Total.Extent <- Elevation + Slope + Aspect + EVI + AgeClss + CrwnDns + HghtCls + LandCover

# Crop layers against total extent to get them to line up
Elevation <- crop(Elevation, Total.Extent)
Slope <- crop(Slope, Total.Extent)
Aspect <- crop(Aspect, Total.Extent)
EVI <- crop(EVI, Total.Extent)
AgeClss <- crop(AgeClss, Total.Extent)
CrwnDns <- crop(CrwnDns, Total.Extent)
HghtCls <- crop(HghtCls, Total.Extent)
LandCover <- crop(LandCover, Total.Extent)

# Put all layers into a raster stack
Raster.stack <- stack(Elevation, Slope, Aspect, EVI, AgeClss, CrwnDns, HghtCls, LandCover)

# Load sample points
Samp.pts <- shapefile("Data/Spatial/ForDistributionModelling/SamplePoints/SamplePoints_StDMs.shp")

# Subset points for the x/y coordinates
SP <- SpatialPoints(coordinates(Samp.pts)[,-3])
# Extract values from StDM rasters for our sample points
SP.raster <- extract(Raster.stack, SP)
# Join extracted raster values back
Samp.pts.raster <- cbind(Samp.pts, SP.raster)
# Convert back to data frame
Samp.pts.returned <- as.data.frame(Samp.pts.raster)
# Save Sample Points with Co-variates as a csv
write.csv(Samp.pts.returned, "Data/Outputs/Covariates/SampPts_CoVariates1.csv")
# For some of the sample locations, information on age class, height class, and crown density were missing, because our sample points was located within a wetland type land cover class in FRI, to correct for spatial inaccuracies I extracted values from the adjacent forest type land cover class.



###### Test for colinearity among covariates ######
# Load elemental modeling and phytochemical data for ABBA and PIMA - test for colinearity among spatial 

# Load the stoichiometry data with biomass, qty, and ratios
FoliageStoich <- read.csv("Data/Outputs/BiomassRatio/BiomassRatioEstimates.csv")
str(FoliageStoich)
# Load Landscape Covariates
StDMs.Covariates <- read.csv("Data/Outputs/Covariates/SampPts_CoVariates_Cleaned.csv")
# Join foliar stoichiometry with landscape covariate data
Spp.Stoi <- merge(FoliageStoich, StDMs.Covariates, by.x="PlotName", by.y="PlotName")
str(Spp.Stoi)
# Set biotic/land cover fields to factors
Spp.Stoi$AgeClss <- as.factor(Spp.Stoi$AgeClss)
Spp.Stoi$HghtCls <- as.factor(Spp.Stoi$HghtCls)
Spp.Stoi$CrwnDns <- as.factor(Spp.Stoi$CrwnDns)
Spp.Stoi$LandCover <- as.factor(Spp.Stoi$LandCover)
str(Spp.Stoi)

# Rename fields for the correlation plot
names(Spp.Stoi)[names(Spp.Stoi) == "LandCover"] <- "Land Cover"
names(Spp.Stoi)[names(Spp.Stoi) == "AgeClss"] <- "Age Class"
names(Spp.Stoi)[names(Spp.Stoi) == "HghtCls"] <- "Height Class"
names(Spp.Stoi)[names(Spp.Stoi) == "CrwnDns"] <- "Crown Density"



# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Subset data by species

# ABBA
Stoi.ABBA <- subset(Spp.Stoi, Species == "ABBA")
Stoi.ABBA$EVI <- c(scale(Stoi.ABBA$EVI.ns))
Stoi.ABBA$Elevation <- c(scale(Stoi.ABBA$Elevation.ns))
Stoi.ABBA$Aspect <- c(scale(Stoi.ABBA$Aspect.ns))
Stoi.ABBA$Slope <- c(scale(Stoi.ABBA$Slope.ns))
str(Stoi.ABBA)

Elements.ABBA <- subset(Stoi.ABBA, select=c("Land Cover", "EVI", "Age Class", "Height Class", "Crown Density", "Elevation", "Aspect", "Slope"))

# Export graph
png("Deliverables/SpatialCoVariate_CorrPlots/ABBA_ElementalTraits.png", width = 8, height = 6, units = "in", res = 600)
pairs.panels(Elements.ABBA, cor = T, hist.col = "grey", method="pearson", rug=F, stars =T)
dev.off()



# ACRU
Stoi.ACRU <- subset(Spp.Stoi, Species == "ACRU")
Stoi.ACRU$EVI <- c(scale(Stoi.ACRU$EVI.ns))
Stoi.ACRU$Elevation <- c(scale(Stoi.ACRU$Elevation.ns))
Stoi.ACRU$Aspect <- c(scale(Stoi.ACRU$Aspect.ns))
Stoi.ACRU$Slope <- c(scale(Stoi.ACRU$Slope.ns))
str(Stoi.ACRU)


Elements.ACRU <- subset(Stoi.ACRU, select=c("Land Cover", "EVI", "Age Class", "Height Class", "Crown Density", "Elevation", "Aspect", "Slope"))

# Export graph
png("Deliverables/SpatialCoVariate_CorrPlots/ACRU_ElementalTraits.png", width = 8, height = 6, units = "in", res = 600)
pairs.panels(Elements.ACRU, cor = T, hist.col = "grey", method="pearson", rug=F, stars =T)
dev.off()




# BEPA
Stoi.BEPA <- subset(Spp.Stoi, Species == "BEPA")
Stoi.BEPA$EVI <- c(scale(Stoi.BEPA$EVI.ns))
Stoi.BEPA$Elevation <- c(scale(Stoi.BEPA$Elevation.ns))
Stoi.BEPA$Aspect <- c(scale(Stoi.BEPA$Aspect.ns))
Stoi.BEPA$Slope <- c(scale(Stoi.BEPA$Slope.ns))
str(Stoi.BEPA)


Elements.BEPA <- subset(Stoi.BEPA, select=c("Land Cover", "EVI", "Age Class", "Height Class", "Crown Density", "Elevation", "Aspect", "Slope"))

# Export graph
png("Deliverables/SpatialCoVariate_CorrPlots/BEPA_ElementalTraits.png", width = 8, height = 6, units = "in", res = 600)
pairs.panels(Elements.BEPA, cor = T, hist.col = "grey", method="pearson", rug=F, stars =T)
dev.off()



# PIMA
Stoi.PIMA <- subset(Spp.Stoi, Species == "PIMA")
Stoi.PIMA$EVI <- c(scale(Stoi.PIMA$EVI.ns))
Stoi.PIMA$Elevation <- c(scale(Stoi.PIMA$Elevation.ns))
Stoi.PIMA$Aspect <- c(scale(Stoi.PIMA$Aspect.ns))
Stoi.PIMA$Slope <- c(scale(Stoi.PIMA$Slope.ns))
str(Stoi.PIMA)



Elements.PIMA <- subset(Stoi.PIMA, select=c("Land Cover", "EVI", "Age Class", "Height Class", "Crown Density", "Elevation", "Aspect", "Slope"))

# Export graph
png("Deliverables/SpatialCoVariate_CorrPlots/PIMA_ElementalTraits.png", width = 8, height = 6, units = "in", res = 600)
pairs.panels(Elements.PIMA, cor = T, hist.col = "grey", method="pearson", rug=F, stars =T)
dev.off()



# VAAN
Stoi.VAAN <- subset(Spp.Stoi, Species == "VAAN")
Stoi.VAAN$EVI <- c(scale(Stoi.VAAN$EVI.ns))
Stoi.VAAN$Elevation <- c(scale(Stoi.VAAN$Elevation.ns))
Stoi.VAAN$Aspect <- c(scale(Stoi.VAAN$Aspect.ns))
Stoi.VAAN$Slope <- c(scale(Stoi.VAAN$Slope.ns))
str(Stoi.VAAN)

Elements.VAAN <- subset(Stoi.VAAN, select=c("Land Cover", "EVI", "Age Class", "Height Class", "Crown Density", "Elevation", "Aspect", "Slope"))

# Export graph
png("Deliverables/SpatialCoVariate_CorrPlots/VAAN_ElementalTraits.png", width = 8, height = 6, units = "in", res = 600)
pairs.panels(Elements.VAAN, cor = T, hist.col = "grey", method="pearson", rug=F, stars =T)
dev.off()






#################################################################################

# Load phytochemistry data for balsam fir
ABBA.Phyto <- read.csv("Data/Phytochemical/ABBA_BiomassBasis_Phytochemistry.csv")
str(ABBA.Phyto)

# Load landscape covariates
LC.Covariates <- read.csv("Data/Outputs/Covariates/SampPts_CoVariates_Cleaned.csv")
str(LC.Covariates)

# Join ABBA phytochemistry to the landscape covariates
bF.Phyto <- merge(ABBA.Phyto, LC.Covariates, by.x="PlotName", by.y="PlotName", all.x=T)


# Set biotic/land cover fields to factors
bF.Phyto$AgeClss <- as.factor(bF.Phyto$AgeClss)
bF.Phyto$HghtCls <- as.factor(bF.Phyto$HghtCls)
bF.Phyto$CrwnDns <- as.factor(bF.Phyto$CrwnDns)
bF.Phyto$LandCover <- as.factor(bF.Phyto$LandCover)

# scale continuous variables
bF.Phyto$EVI <- c(scale(bF.Phyto$EVI.ns))
bF.Phyto$Elevation <- c(scale(bF.Phyto$Elevation.ns))
bF.Phyto$Aspect <- c(scale(bF.Phyto$Aspect.ns))
bF.Phyto$Slope <- c(scale(bF.Phyto$Slope.ns))
str(bF.Phyto)

# Rename fields for the correlation plot
names(bF.Phyto)[names(bF.Phyto) == "LandCover"] <- "Land Cover"
names(bF.Phyto)[names(bF.Phyto) == "AgeClss"] <- "Age Class"
names(bF.Phyto)[names(bF.Phyto) == "HghtCls"] <- "Height Class"
names(bF.Phyto)[names(bF.Phyto) == "CrwnDns"] <- "Crown Density"


Phyto.ABBA <- subset(bF.Phyto, select=c("Land Cover", "EVI", "Age Class", "Height Class", "Crown Density", "Elevation", "Aspect", "Slope"))

# Export graph
png("Deliverables/SpatialCoVariate_CorrPlots/ABBA_PhytoTraits.png", width = 8, height = 6, units = "in", res = 600)
pairs.panels(Phyto.ABBA, cor = T, hist.col = "grey", method="pearson", rug=F, stars =T)
dev.off()





# Load phytochemistry data for black spruce
PIMA.Phyto <- read.csv("Data/Phytochemical/PIMA_BiomassBasis_Phytochemistry.csv")
str(PIMA.Phyto)

# Load landscape covariates
LC.Covariates <- read.csv("Data/Outputs/Covariates/SampPts_CoVariates_Cleaned.csv")
str(LC.Covariates)

# Join ABBA phytochemistry to the landscape covariates
bS.Phyto <- merge(PIMA.Phyto, LC.Covariates, by.x="PlotName", by.y="PlotName", all.x=T)
str(bS.Phyto)

# Set biotic/land cover fields to factors
bS.Phyto$AgeClss <- as.factor(bS.Phyto$AgeClss.x)
bS.Phyto$HghtCls <- as.factor(bS.Phyto$HghtCls.x)
bS.Phyto$CrwnDns <- as.factor(bS.Phyto$CrwnDns.x)
bS.Phyto$LandCover <- as.factor(bS.Phyto$LandCover.x)

# scale continuous variables
bS.Phyto$EVI <- c(scale(bS.Phyto$EVI.ns.x))
bS.Phyto$Elevation <- c(scale(bS.Phyto$Elevation.ns.x))
bS.Phyto$Aspect <- c(scale(bS.Phyto$Aspect.ns.x))
bS.Phyto$Slope <- c(scale(bS.Phyto$Slope.ns.x))
str(bS.Phyto)

# Rename fields for the correlation plot
names(bS.Phyto)[names(bS.Phyto) == "LandCover"] <- "Land Cover"
names(bS.Phyto)[names(bS.Phyto) == "AgeClss"] <- "Age Class"
names(bS.Phyto)[names(bS.Phyto) == "HghtCls"] <- "Height Class"
names(bS.Phyto)[names(bS.Phyto) == "CrwnDns"] <- "Crown Density"


Phyto.PIMA <- subset(bS.Phyto, select=c("Land Cover", "EVI", "Age Class", "Height Class", "Crown Density", "Elevation", "Aspect", "Slope"))

# Export graph
png("Deliverables/SpatialCoVariate_CorrPlots/PIMA_PhytoTraits.png", width = 8, height = 6, units = "in", res = 600)
pairs.panels(Phyto.PIMA, cor = T, hist.col = "grey", method="pearson", rug=F, stars =T)
dev.off()
